@@ -14,20 +14,22 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-var Iconv = require('../lib/iconv').Iconv;
-var assert = require('assert');
+'use strict';
 
-var iconv = new Iconv('UTF-8', 'UTF-16LE');
+const Iconv = require('../').Iconv;
+const assert = require('assert');
 
-var utf8 = new Buffer(20000000);
-for (var i = 0; i < utf8.length; i++) {
+const iconv = new Iconv('UTF-8', 'UTF-16LE');
+
+const utf8 = Buffer.alloc(20000000);
+for (let i = 0; i < utf8.length; i++) {
   utf8[i] = 97 + i % 26; // cycle from 'a' to 'z'.
 }
-var utf16 = iconv.convert(utf8);
+const utf16 = iconv.convert(utf8);
 
 assert.equal(utf16.length, utf8.length * 2);
 
-for (i = 0; i < utf8.length; ++i) {
+for (let i = 0; i < utf8.length; ++i) {
   assert.equal(utf16[i * 2], utf8[i]);
   assert.equal(utf16[i * 2 + 1], 0);
 }
